<?php
/**
 * The template for displaying archive pages.
 *
 * @link https://slovenskoit.sk
 *
 * @package WordPress
 * @subpackage ID-SK
 * @since ID-SK 1.3.0
 */

get_header();

$archive_desc = get_the_archive_description();

if ( have_posts() ) {
	?>
	<div class="govuk-width-container">

		<h1 class="govuk-heading-xl">
			<?php
			echo wp_kses_post( get_the_archive_title() );

			if ( $archive_desc ) {
				?>
				<span class="govuk-caption-xl"><?php echo wp_kses_post( $archive_desc ); ?></span>
				<?php
			}
			?>
		</h1>

		<?php
		$index = 0;

		while ( have_posts() ) {
			the_post();

			if ( has_post_thumbnail() ) {
				$image_link = get_the_post_thumbnail_url( null, 'full' );
			} else {
				$image_link = get_template_directory_uri() . '/assets/images/image-placeholder.jpg';
			}

			$post_data = array(
				'title'      => get_the_title(),
				'url'        => get_permalink(),
				'created'    => get_the_date(),
				'image'      => $image_link,
				'excerpt'    => get_the_excerpt(),
				'categories' => get_the_category(),
			);

			if ( 0 === $index ) {
				?>
				<div class="govuk-grid-row">
					<div class="govuk-grid-column-full">
						<?php idsktmp_post_detail( $post_data, 'hero' ); ?>
					</div>
				</div>
				<?php
			} else {
				if ( 1 === $index % 3 ) {
					?>
					<div class="govuk-grid-row">
					<?php
				}
				?>

				<div class="govuk-grid-column-one-third">
					<?php idsktmp_post_detail( $post_data, 'secondary' ); ?>
				</div>

				<?php
				if ( 0 === $index % 3 || $wp_query->post_count === $index + 1 ) {
					?>
					</div>
					<?php
				}
			}

			$index++;
		}

		idsktmp_posts_pagination();
}

get_footer();
