/**
 * Wordpress Contact Form 7
 * ID-SK form error messages functionality
 * and ID-SK form summary message style.
 */

document.addEventListener( 'wpcf7spam', function( event ) { idskShowSummaryMessage( event ) }, false );
document.addEventListener( 'wpcf7mailsent', function( event ) { idskShowSummaryMessage( event, 'success' ) }, false );
document.addEventListener( 'wpcf7mailfailed', function( event ) { idskShowSummaryMessage( event ) }, false );

document.addEventListener( 'wpcf7invalid', function( event ) {
    var $form = document.querySelector(event.detail.apiResponse.into);
    var $errorsList = event.detail.apiResponse.invalid_fields;
    var $idskErrorMessages = $form.querySelectorAll('.govuk-error-message');
    var $errors = [];

    // Fill up errors array
    $errorsList.forEach(function($error) {
        var $formGroup = $form.querySelector($error['into']).closest('.govuk-form-group');

        if ($formGroup) {
            $errors.push({
                'id'        : $error['idref'],
                'name'      : $formGroup.querySelector('label').textContent,
                'refname'   : /[^.]*$/.exec($error['into'])[0]
            });
        }
    });

    // Show ID-SK input error
    $idskErrorMessages.forEach(function($item) {
        var $formGroup = $item.closest('.govuk-form-group');

        if ($formGroup) {
            var $wpcf7input = $formGroup.querySelector('.wpcf7-form-control');

            // Hide by default
            $formGroup.classList.remove('govuk-form-group--error');
            $wpcf7input.classList.remove('govuk-input--error');
            $item.style.display = 'none';

            // Show on error
            if ($errors.length > 0) {
                for (var i = 0; i < $errors.length; i++) {
                    if ($wpcf7input.getAttribute('name') == $errors[i]['refname']) {
                        $formGroup.classList.add('govuk-form-group--error');
                        $wpcf7input.classList.add('govuk-input--error');
                        $item.style.display = 'block';

                        // Hide WordPress Contact Form 7 error
                        setTimeout(function() {
                            $formGroup.querySelector('.wpcf7-not-valid-tip').style.display = 'none';
                        }, 500);
                    }
                }
            }
        }
    });

    idskShowSummaryMessage( event, 'error', $errors );
}, false );

/**
 * Error summary message
 * @param {string} content Summary message
 * @param {string} type Type of form summary
 * @param {array} errors Array of errors
 * @returns {string}
 */
function idskErrorSummary(content, type = '', errors = []) {
    let className = ''

    switch (type) {
        case 'success':
            className = 'idsk-error-summary-success';
            break;
        default:
            break;
    }

    output = '<div class="govuk-error-summary '+className+'" aria-labelledby="error-summary-title" role="alert" tabindex="-1" data-module="govuk-error-summary">';
    output += '<h2 class="govuk-error-summary__title" id="error-summary-title">';
    output += content;
    output += '</h2>';

    if (errors.length > 0) {
        output += '<div class="govuk-error-summary__body">';
        output += '<ul class="govuk-list govuk-error-summary__list">';

        errors.forEach(error => {
            output += '<li>';
            if (error.id != null) {
                output += '<a href="#'+error.id+'">'+error.name+'</a>';
            } else {
                output += error.name;
            }
            output += '</li>';
        });

        output += '</ul>';
        output += '</div>';
    }

    output += '</div>';

    return output;
}

/**
 * Shows ID-SK summary message and hides WordPress Contact Form 7 response message
 * @param {object} element 
 * @param {string} type Type of form summary
 * @param {array} errors Array of errors
 */
function idskShowSummaryMessage(element, type = '', errors = []) {
    var $form = document.querySelector(element.detail.apiResponse.into);
    var $responseMessage = element.detail.apiResponse.message;
    var $wpcf7ResponseMessage = $form.querySelector('.wpcf7-response-output');
    
    // Hide ID-SK error summary if present
    if ($form.querySelector('.govuk-error-summary')) {
        $form.querySelector('.govuk-error-summary').remove();
    }

    // Show ID-SK error summary
    $wpcf7ResponseMessage.style.display = 'none';
    $form.insertAdjacentHTML('afterbegin', idskErrorSummary($responseMessage, type, errors));
    $form.querySelector('.govuk-error-summary').focus();
}