<?php
/**
 * Customizer settings for this theme.
 *
 * @package WordPress
 * @subpackage ID-SK
 * @since ID-SK 1.0
 */

if ( ! class_exists( 'Idsktmp_Customize' ) ) {

	/**
	 * CUSTOMIZER SETTINGS
	 */
	class Idsktmp_Customize {
		/**
		 * Register customizer options.
		 *
		 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
		 */
		public static function idsktmp_register( $wp_customize ) {

			/**
			 * Header Extended panel
			 */
			$wp_customize->add_panel(
				'idsktmp_header_extended_panel',
				array(
					'title'      => __( 'Header for websites', 'idsk-template' ),
					'priority'   => 30,
					'capability' => 'edit_theme_options',
				)
			);

				/**
				 * Info banner section.
				 */
				$wp_customize->add_section(
					'idsktmp_global_info_section',
					array(
						'title'    => __( 'Banner', 'idsk-template' ),
						'priority' => 10,
						'panel'    => 'idsktmp_header_extended_panel',
					)
				);

					// Global info.
					$wp_customize->add_setting(
						'idsktmp_main_settings_global_info',
						array(
							'sanitize_callback' => array( __CLASS__, 'idsktmp_sanitize_text' ),
						)
					);
					$wp_customize->add_control(
						'idsktmp_main_settings_global_info_control',
						array(
							'label'    => __( 'Global information on website', 'idsk-template' ),
							'section'  => 'idsktmp_global_info_section',
							'settings' => 'idsktmp_main_settings_global_info',
							'type'     => 'textarea',
						)
					);
					$wp_customize->add_setting(
						'idsktmp_main_settings_global_info_type',
						array(
							'default'           => 'info',
							'sanitize_callback' => array( __CLASS__, 'idsktmp_sanitize_radio' ),
						)
					);
					$wp_customize->add_control(
						'idsktmp_main_settings_global_info_type',
						array(
							'label'    => __( 'Banner type', 'idsk-template' ),
							'section'  => 'idsktmp_global_info_section',
							'settings' => 'idsktmp_main_settings_global_info_type',
							'type'     => 'radio',
							'choices'  => array(
								'info'    => __( 'Information banner', 'idsk-template' ),
								'warning' => __( 'Warning banner', 'idsk-template' ),
							),
						)
					);

					$wp_customize->add_setting(
						'idsktmp_main_settings_global_info_close',
						array(
							'capability'        => 'edit_theme_options',
							'default'           => false,
							'sanitize_callback' => array( __CLASS__, 'idsktmp_sanitize_checkbox' ),
						)
					);
					$wp_customize->add_control(
						'idsktmp_main_settings_global_info_close',
						array(
							'label'   => __( 'Allow closing of banner', 'idsk-template' ),
							'section' => 'idsktmp_global_info_section',
							'type'    => 'checkbox',
						)
					);

				/**
				 * Gestor banner section.
				 */
				$wp_customize->add_section(
					'idsktmp_gestor_banner_section',
					array(
						'title'    => __( 'Information bar', 'idsk-template' ),
						'priority' => 20,
						'panel'    => 'idsktmp_header_extended_panel',
					)
				);

					// Gestor banner.
					$wp_customize->add_setting(
						'idsktmp_setting_gestor_banner_text',
						array(
							'sanitize_callback' => array( __CLASS__, 'idsktmp_sanitize_text' ),
						)
					);
					$wp_customize->add_control(
						'idsktmp_setting_gestor_banner_text',
						array(
							'label'   => __( 'Panel text', 'idsk-template' ),
							'section' => 'idsktmp_gestor_banner_section',
							'type'    => 'text',
						)
					);

					$wp_customize->add_setting(
						'idsktmp_setting_gestor_banner_text_mobile',
						array(
							'sanitize_callback' => array( __CLASS__, 'idsktmp_sanitize_text' ),
						)
					);
					$wp_customize->add_control(
						'idsktmp_setting_gestor_banner_text_mobile',
						array(
							'label'   => __( 'Abbreviated panel text for mobile devices', 'idsk-template' ),
							'section' => 'idsktmp_gestor_banner_section',
							'type'    => 'text',
						)
					);

					$wp_customize->add_setting(
						'idsktmp_setting_gestor_banner_button',
						array(
							'sanitize_callback' => array( __CLASS__, 'idsktmp_sanitize_text' ),
						)
					);
					$wp_customize->add_control(
						'idsktmp_setting_gestor_banner_button',
						array(
							'label'       => __( 'Panel button text', 'idsk-template' ),
							'description' => __( 'Text for button that opens additional informations about the website', 'idsk-template' ),
							'section'     => 'idsktmp_gestor_banner_section',
							'type'        => 'text',
						)
					);

					$wp_customize->add_setting(
						'idsktmp_setting_gestor_banner_button_mobile',
						array(
							'sanitize_callback' => array( __CLASS__, 'idsktmp_sanitize_text' ),
						)
					);
					$wp_customize->add_control(
						'idsktmp_setting_gestor_banner_button_mobile',
						array(
							'label'       => __( 'Abbreviated panel button text for mobile devices', 'idsk-template' ),
							'description' => __( 'Text for button that opens additional informations about the website', 'idsk-template' ),
							'section'     => 'idsktmp_gestor_banner_section',
							'type'        => 'text',
						)
					);

					$wp_customize->add_setting(
						'idsktmp_setting_gestor_banner_more_info',
						array(
							'sanitize_callback' => array( __CLASS__, 'idsktmp_sanitize_text' ),
						)
					);
					$wp_customize->add_control(
						'idsktmp_setting_gestor_banner_more_info',
						array(
							'label'       => __( 'Additional website informations', 'idsk-template' ),
							'description' => __( 'The following HTML tags are allowed: div, h3, p, a, strong', 'idsk-template' ),
							'section'     => 'idsktmp_gestor_banner_section',
							'type'        => 'textarea',
						)
					);

				/**
				 * Header basic settings section.
				 */
				$wp_customize->add_section(
					'idsktmp_header_extended',
					array(
						'title'    => __( 'Basic settings', 'idsk-template' ),
						'priority' => 30,
						'panel'    => 'idsktmp_header_extended_panel',
					)
				);

					// Header Extended - Logo.
					$wp_customize->add_setting(
						'idsktmp_main_logo',
						array(
							'sanitize_callback' => array( __CLASS__, 'idsktmp_sanitize_images' ),
						)
					);
					$wp_customize->add_control(
						new WP_Customize_Image_Control(
							$wp_customize,
							'idsktmp_main_logo',
							array(
								'label'       => __( 'Upload logo', 'idsk-template' ),
								'section'     => 'idsktmp_header_extended',
								'settings'    => 'idsktmp_main_logo',
								'description' => __( 'Website logo - colored', 'idsk-template' ),
							)
						)
					);

					// Header Extended - Search.
					$wp_customize->add_setting(
						'idsktmp_enable_header_search',
						array(
							'capability'        => 'edit_theme_options',
							'default'           => true,
							'sanitize_callback' => array( __CLASS__, 'idsktmp_sanitize_checkbox' ),
						)
					);
					$wp_customize->add_control(
						'idsktmp_enable_header_search',
						array(
							'type'     => 'checkbox',
							'section'  => 'idsktmp_header_extended',
							'priority' => 10,
							'label'    => __( 'Show search in header', 'idsk-template' ),
						)
					);

					// Header custom button.
					$wp_customize->add_setting(
						'idsktmp_setting_header_custom_button_link',
						array(
							'sanitize_callback' => 'esc_url_raw',
						)
					);
					$wp_customize->add_control(
						'idsktmp_setting_header_custom_button_link_control',
						array(
							'label'    => __( 'Custom button - link', 'idsk-template' ),
							'section'  => 'idsktmp_header_extended',
							'settings' => 'idsktmp_setting_header_custom_button_link',
							'type'     => 'url',
						)
					);

					$wp_customize->add_setting(
						'idsktmp_setting_header_custom_button_target',
						array(
							'capability'        => 'edit_theme_options',
							'default'           => true,
							'sanitize_callback' => array( __CLASS__, 'idsktmp_sanitize_checkbox' ),
						)
					);
					$wp_customize->add_control(
						'idsktmp_setting_header_custom_button_target',
						array(
							'type'    => 'checkbox',
							'section' => 'idsktmp_header_extended',
							'label'   => __( 'Open in new window', 'idsk-template' ),
						)
					);

					$wp_customize->add_setting(
						'idsktmp_setting_header_custom_button_text',
						array(
							'sanitize_callback' => array( __CLASS__, 'idsktmp_sanitize_text' ),
						)
					);
					$wp_customize->add_control(
						'idsktmp_setting_header_custom_button_text',
						array(
							'label'   => __( 'Custom button - text', 'idsk-template' ),
							'section' => 'idsktmp_header_extended',
							'type'    => 'text',
						)
					);

			/**
			 * Footer extended section.
			 */
			$wp_customize->add_section(
				'idsktmp_footer_extened',
				array(
					'title'    => __( 'Footer for websites', 'idsk-template' ),
					'priority' => 31,
				)
			);

				// Footer extended - Logo.
				$wp_customize->add_setting(
					'idsktmp_footer_extended_logo',
					array(
						'sanitize_callback' => array( __CLASS__, 'idsktmp_sanitize_images' ),
					)
				);
				$wp_customize->add_control(
					new WP_Customize_Image_Control(
						$wp_customize,
						'idsktmp_footer_extended_logo',
						array(
							'label'    => __( 'Upload footer logo - white', 'idsk-template' ),
							'section'  => 'idsktmp_footer_extened',
							'settings' => 'idsktmp_footer_extended_logo',
						)
					)
				);

				// Footer extended - Up-button.
				$wp_customize->add_setting(
					'idsktmp_footer_exteded_up_button',
					array(
						'capability'        => 'edit_theme_options',
						'default'           => true,
						'sanitize_callback' => array( __CLASS__, 'idsktmp_sanitize_checkbox' ),
					)
				);
				$wp_customize->add_control(
					'idsktmp_footer_exteded_up_button',
					array(
						'type'     => 'checkbox',
						'section'  => 'idsktmp_footer_extened',
						'priority' => 10,
						'label'    => __( 'Show up-button in footer', 'idsk-template' ),
					)
				);

				// Footer extended - Feedback form.
				$wp_customize->add_setting(
					'idsktmp_footer_exteded_feedback_form',
					array(
						'capability'        => 'edit_theme_options',
						'default'           => true,
						'sanitize_callback' => array( __CLASS__, 'idsktmp_sanitize_checkbox' ),
					)
				);
				$wp_customize->add_control(
					'idsktmp_footer_exteded_feedback_form',
					array(
						'type'     => 'checkbox',
						'section'  => 'idsktmp_footer_extened',
						'priority' => 10,
						'label'    => __( 'Show feedback form in footer', 'idsk-template' ),
					)
				);
				// If idsktmp_footer_exteded_feedback_form is checked, show these settings.
				// Set feedback title.
				$wp_customize->add_setting(
					'idsktmp_footer_exteded_feedback_title',
					array(
						'sanitize_callback' => array( __CLASS__, 'idsktmp_sanitize_text' ),
					)
				);
				$wp_customize->add_control(
					'idsktmp_footer_exteded_feedback_title_control',
					array(
						'label'           => __( 'Satisfaction survey - title', 'idsk-template' ),
						'section'         => 'idsktmp_footer_extened',
						'settings'        => 'idsktmp_footer_exteded_feedback_title',
						'type'            => 'text',
						'active_callback' => array( __CLASS__, 'idsktmp_is_footer_extended_feedback_form' ),
					)
				);
				// Set feedback content.
				$wp_customize->add_setting(
					'idsktmp_footer_exteded_feedback_content',
					array(
						'sanitize_callback' => array( __CLASS__, 'idsktmp_sanitize_text' ),
					)
				);
				$wp_customize->add_control(
					'idsktmp_footer_exteded_feedback_content_control',
					array(
						'label'           => __( 'Satisfaction survey - Content', 'idsk-template' ),
						'section'         => 'idsktmp_footer_extened',
						'settings'        => 'idsktmp_footer_exteded_feedback_content',
						'type'            => 'textarea',
						'active_callback' => array( __CLASS__, 'idsktmp_is_footer_extended_feedback_form' ),
					)
				);
				// Set feedback endpoint link.
				$wp_customize->add_setting(
					'idsktmp_footer_exteded_feedback_link',
					array(
						'sanitize_callback' => 'esc_url_raw', // Cleans URL from all invalid characters.
					)
				);
				$wp_customize->add_control(
					'idsktmp_footer_exteded_feedback_link_control',
					array(
						'label'           => __( 'Satisfaction survey - URL', 'idsk-template' ),
						'section'         => 'idsktmp_footer_extened',
						'settings'        => 'idsktmp_footer_exteded_feedback_link',
						'type'            => 'url',
						'active_callback' => array( __CLASS__, 'idsktmp_is_footer_extended_feedback_form' ),
					)
				);

			/**
			 * Theme basic settings.
			 */
			$wp_customize->add_section(
				'idsktmp_main_settings',
				array(
					'title'    => __( 'Theme main settings', 'idsk-template' ),
					'priority' => 10,
				)
			);

				// Show breadcrumbs on subpages.
				$wp_customize->add_setting(
					'idsktmp_show_breadcrumbs',
					array(
						'capability'        => 'edit_theme_options',
						'default'           => false,
						'sanitize_callback' => array( __CLASS__, 'idsktmp_sanitize_checkbox' ),
					)
				);
				$wp_customize->add_control(
					'idsktmp_show_breadcrumbs',
					array(
						'type'    => 'checkbox',
						'section' => 'idsktmp_main_settings',
						'label'   => __( 'Show breadcrumbs on subpages', 'idsk-template' ),
					)
				);

				// Show version info.
				$wp_customize->add_setting(
					'idsktmp_show_version_info',
					array(
						'sanitize_callback' => array( __CLASS__, 'idsktmp_sanitize_text' ),
					)
				);
				$wp_customize->add_control(
					'idsktmp_show_version_info',
					array(
						'label'       => __( 'Website version', 'idsk-template' ),
						'description' => __( 'If version is not entered, block will not show.', 'idsk-template' ),
						'section'     => 'idsktmp_main_settings',
						'settings'    => 'idsktmp_show_version_info',
						'type'        => 'text',
					)
				);

				$wp_customize->add_setting(
					'idsktmp_show_version_info_text',
					array(
						'sanitize_callback' => array( __CLASS__, 'idsktmp_sanitize_text' ),
					)
				);
				$wp_customize->add_control(
					'idsktmp_show_version_info_text',
					array(
						'label'    => __( 'Text information on website version', 'idsk-template' ),
						'section'  => 'idsktmp_main_settings',
						'settings' => 'idsktmp_show_version_info_text',
						'type'     => 'text',
					)
				);

				$wp_customize->add_setting(
					'idsktmp_show_version_info_date',
					array(
						'sanitize_callback' => array( __CLASS__, 'idsktmp_sanitize_text' ),
					)
				);
				$wp_customize->add_control(
					'idsktmp_show_version_info_date',
					array(
						'label'    => __( 'Date of publication of website version', 'idsk-template' ),
						'section'  => 'idsktmp_main_settings',
						'settings' => 'idsktmp_show_version_info_date',
						'type'     => 'text',
					)
				);

			/**
			 * Alert panel.
			 */
			$wp_customize->add_section(
				'idsktmp_alert_panel',
				array(
					'title'       => __( 'Warning panel', 'idsk-template' ),
					'description' => __( "Shows panel in the page header. Panel's name must be entered for the panel to show.", 'idsk-template' ),
					'priority'    => 15,
				)
			);

				// Confirmation panel.
				$wp_customize->add_setting(
					'idsktmp_alert_panel_success',
					array(
						'capability'        => 'edit_theme_options',
						'default'           => false,
						'sanitize_callback' => array( __CLASS__, 'idsktmp_sanitize_checkbox' ),
					)
				);
				$wp_customize->add_control(
					'idsktmp_alert_panel_success',
					array(
						'type'    => 'checkbox',
						'section' => 'idsktmp_alert_panel',
						'label'   => __( 'Show confirmation panel', 'idsk-template' ),
					)
				);

				// Panel heading.
				$wp_customize->add_setting(
					'idsktmp_alert_panel_heading',
					array(
						'sanitize_callback' => array( __CLASS__, 'idsktmp_sanitize_text' ),
					)
				);
				$wp_customize->add_control(
					'idsktmp_alert_panel_heading',
					array(
						'label'   => __( 'Panel heading', 'idsk-template' ),
						'section' => 'idsktmp_alert_panel',
						'type'    => 'text',
					)
				);

				// Panel text.
				$wp_customize->add_setting(
					'idsktmp_alert_panel_text',
					array(
						'sanitize_callback' => array( __CLASS__, 'idsktmp_sanitize_text' ),
					)
				);
				$wp_customize->add_control(
					'idsktmp_alert_panel_text',
					array(
						'label'   => __( "Panel's text content", 'idsk-template' ),
						'section' => 'idsktmp_alert_panel',
						'type'    => 'textarea',
					)
				);

		}

		/**
		 * Check if footer_extended_feedback_form is allowed.
		 *
		 * @return bool
		 */
		public static function idsktmp_is_footer_extended_feedback_form() {
			return true === get_theme_mod( 'idsktmp_footer_exteded_feedback_form', true );
		}

		/**
		 * Sanitize boolean for checkbox.
		 *
		 * @param bool $checked Whether or not a box is checked.
		 * @return bool
		 */
		public static function idsktmp_sanitize_checkbox( $checked ) {
			return ( ( isset( $checked ) && true === $checked ) ? true : false );
		}

		/**
		 * Sanitize images for uploads.
		 *
		 * @param resource $file    File for sanitization.
		 * @param object   $setting Settings object.
		 * @return image
		 */
		public static function idsktmp_sanitize_images( $file, $setting ) {
			// Allowed file types.
			$mimes = array(
				'jpg|jpeg|jpe' => 'image/jpeg',
				'gif'          => 'image/gif',
				'png'          => 'image/png',
				'bmp'          => 'image/bmp',
				'svg'          => 'image/svg+xml',
			);

			// Check file type from file name.
			$file_ext = wp_check_filetype( $file, $mimes );

			// If file has a valid mime type return it, otherwise return default.
			return ( $file_ext['ext'] ? $file : $setting->default );
		}

		/**
		 * Sanitize radio controls.
		 *
		 * @param string $input   Input to sanitize.
		 * @param object $setting Settings object.
		 * @return string
		 */
		public static function idsktmp_sanitize_radio( $input, $setting ) {
			// Ensure input is a slug.
			$input = sanitize_key( $input );
			// Get list of choices from the control associated with the setting.
			$choices = $setting->manager->get_control( $setting->id )->choices;
			// If the input is a valid key, return it; otherwise, return the default.
			return ( array_key_exists( $input, $choices ) ? $input : $setting->default );
		}

		/**
		 * Sanitize text.
		 *
		 * @param string $string String to sanitize.
		 * @return string
		 */
		public static function idsktmp_sanitize_text( $string ) {
			$allowedtags = array(
				'div'    => array(
					'class' => array(),
				),
				'h3'     => array(
					'class' => array(),
				),
				'p'      => array(
					'class' => array(),
				),
				'strong' => array(),
				'a'      => array(
					'href'       => array(),
					'title'      => array(),
					'class'      => array(),
					'target'     => array(),
					'aria-label' => array(),
					'id'         => array(),
				),
			);

			return wp_kses( $string, $allowedtags );
		}

	}

	add_action( 'customize_register', array( 'Idsktmp_Customize', 'idsktmp_register' ) );

}
