<?php
/**
 * Functions and definitions.
 *
 * @link https://slovenskoit.sk
 *
 * @package WordPress
 * @subpackage ID-SK
 * @since ID-SK 1.0
 */

if ( ! isset( $content_width ) ) {
	$content_width = 1920;
}

/**
 * Include the TGM_Plugin_Activation class.
 */
require get_template_directory() . '/classes/class-tgm-plugin-activation.php';
add_action( 'tgmpa_register', 'idsktmp_register_required_plugins' );

/**
 * Register the required plugins for this theme.
 *
 * This function is hooked into tgmpa_init, which is fired within the
 * TGM_Plugin_Activation class constructor.
 */
function idsktmp_register_required_plugins() {
	/*
	 * Array of plugin arrays.
	 */
	$plugins = array(
		array(
			'name'     => esc_html__( 'ID-SK Toolkit', 'idsk-template' ),
			'slug'     => 'idsk-toolkit',
			'required' => false,
			'version'  => '1.6.0',
		),
		array(
			'name'     => esc_html__( 'ID-SK Demo Data', 'idsk-template' ),
			'slug'     => 'idsk-demodata',
			'required' => false,
		),
		array(
			'name'     => esc_html__( 'Contact Form 7', 'idsk-template' ),
			'slug'     => 'contact-form-7',
			'required' => false,
		),
	);

	/*
	 * Array of configuration settings.
	 */
	$config = array(
		'id'           => 'idsktmp',               // Unique ID for hashing notices for multiple instances of TGMPA.
		'default_path' => '',                      // Default absolute path to bundled plugins.
		'menu'         => 'tgmpa-install-plugins', // Menu slug.
		'has_notices'  => true,                    // Show admin notices or not.
		'dismissable'  => true,                    // If false, a user cannot dismiss the nag message.
		'dismiss_msg'  => '',                      // If 'dismissable' is false, this message will be output at top of nag.
		'is_automatic' => false,                   // Automatically activate plugins after installation or not.
		'message'      => '',                      // Message to output right before the plugins table.
	);

	tgmpa( $plugins, $config );
}

/**
 * Register and Enqueue Styles.
 */
function idsktmp_register_styles() {
	$theme_version = wp_get_theme()->get( 'Version' );

	wp_enqueue_style( 'idsktmp-style', get_stylesheet_uri(), array(), $theme_version );
	wp_enqueue_style( 'idsktmp-search-form', get_template_directory_uri() . '/assets/css/search-form.css', null, $theme_version );

	// Load webfonts.
	wp_enqueue_style( 'idsktmp-fonts', get_stylesheet_directory_uri() . '/assets/fonts/fonts.css', null, $theme_version );
}

add_action( 'wp_enqueue_scripts', 'idsktmp_register_styles' );

/**
 * Register and Enqueue Scripts.
 */
function idsktmp_register_scripts() {
	$theme_version = wp_get_theme()->get( 'Version' );

	wp_enqueue_script( 'idsktmp-js', get_template_directory_uri() . '/assets/js/index.js', array(), $theme_version, true );
	wp_enqueue_script( 'idsktmp-js-feedback', get_template_directory_uri() . '/assets/js/feedback.js', array(), $theme_version, true );
	wp_enqueue_script( 'idsktmp-js-searchform', get_template_directory_uri() . '/assets/js/searchform.js', array(), $theme_version, true );
	wp_enqueue_script( 'idsktmp-js-contact-form', get_template_directory_uri() . '/assets/js/contact-form.js', array(), $theme_version, true );
	wp_enqueue_script( 'idsktmp-js-article', get_template_directory_uri() . '/assets/js/article.js', array(), $theme_version, true );
	wp_enqueue_script( 'idsktmp-js-govuk-init', get_template_directory_uri() . '/assets/js/govuk-init.js', array(), $theme_version, true );

}

add_action( 'wp_enqueue_scripts', 'idsktmp_register_scripts' );

/**
 * Custom logo and theme support.
 */
function idsktmp_custom_logo_setup() {
	$defaults = array(
		'height'      => 120,
		'width'       => 90,
		'flex-height' => true,
		'flex-width'  => true,
	);

	add_theme_support( 'custom-logo', $defaults );
	add_theme_support( 'title-tag' );
	add_theme_support( 'automatic-feed-links' );
	add_theme_support( 'post-thumbnails' );
}

add_action( 'after_setup_theme', 'idsktmp_custom_logo_setup' );

// Handle Customizer settings.
require get_template_directory() . '/classes/class-idsktmp-customize.php';

/**
 * Custom main menu.
 */
function idsktmp_custom_new_menu() {
	register_nav_menus(
		array(
			'primary_menu' => __( 'Main menu', 'idsk-template' ),
			'footer_menu'  => __( 'Footer menu', 'idsk-template' ),
		)
	);
}
add_action( 'init', 'idsktmp_custom_new_menu' );

/**
 * Custom widgets.
 */
function idsktmp_widgets_init() {
	/**
	 * Footer widget - Basic data.
	 */
	register_sidebar(
		array(
			'name'          => __( 'Footer - basic data', 'idsk-template' ),
			'id'            => 'sidebar-3',
			'description'   => __( 'After adding the "Text" widget insert the content shown to the left of the footer logo.', 'idsk-template' ),
			'before_widget' => '',
			'after_widget'  => '',
			'before_title'  => '',
			'after_title'   => '',
		)
	);
	/**
	 * Footer widget - Form - Have you found an error on the page?
	 */
	register_sidebar(
		array(
			'name'          => __( 'Footer - Feedback form - Have you found an error on the page?', 'idsk-template' ),
			'id'            => 'sidebar-4',
			'description'   => __( 'After adding the "Text" widget, insert the link to the contact form you created with the Contact Form 7 plugin (example: [contact-form-7 id="95" title="Help us improve the page"])', 'idsk-template' ),
			'before_widget' => '',
			'after_widget'  => '',
			'before_title'  => '',
			'after_title'   => '',
		)
	);
	/**
	 * Footer widget - Simple navigation.
	 */
	register_sidebar(
		array(
			'name'          => __( 'Footer - Simple navigation', 'idsk-template' ),
			'id'            => 'sidebar-1',
			'description'   => __( 'After adding the "Text" widget, insert the required content with simple navigation.', 'idsk-template' ),
			'before_widget' => '',
			'after_widget'  => '',
			'before_title'  => '',
			'after_title'   => '',
		)
	);
	/**
	 * Footer widget - Extended navigation.
	 */
	register_sidebar(
		array(
			'name'          => __( 'Footer - Extended navigation', 'idsk-template' ),
			'id'            => 'sidebar-2',
			'description'   => __( 'After adding the "Text" widget, insert the required content with extended navigation.', 'idsk-template' ),
			'before_widget' => '',
			'after_widget'  => '',
			'before_title'  => '',
			'after_title'   => '',
		)
	);
}
add_action( 'widgets_init', 'idsktmp_widgets_init' );

// Custom template functions tags for the theme.
require get_template_directory() . '/inc/partials/template-functions.php';
require get_template_directory() . '/inc/partials/template-tags.php';
