<?php
/**
 * Advanced search template.
 *
 * Works only when advanced search is availiable.
 *
 * @link https://slovenskoit.sk
 *
 * @package WordPress
 * @subpackage ID-SK
 * @since ID-SK 1.1.0
 */

$main_search = get_theme_mod( 'idsktk_search_settings_main_show' );

// Get query.
$search_string = get_query_var( 's' );
$ordered_by    = get_query_var( 'orderby' );
if ( empty( $ordered_by ) ) {
	$ordered = get_query_var( 'order' );
} else {
	$ordered = '';
}
$category     = get_query_var( 'cat' );
$sub_category = get_query_var( 'scat' );
$date_from    = get_query_var( 'datum-od' );
$date_to      = get_query_var( 'datum-do' );
// Get tags array.
$tags = get_query_var( 'tags', array() );
?>

<form id="advanced-searchform" role="search" method="get" action="<?php echo esc_url( home_url( '/' ) ); ?>">
	<div class="govuk-grid-column-full idsk-search-results__search-bar <?php echo ! $main_search ? 'idsk-search-results--visible__mobile--inline' : ''; ?>">
		<?php
		get_template_part(
			'inc/partials/search/bar',
			'',
			array(
				'input'  => $search_string,
				'noname' => $main_search ? true : false,
			)
		);
		?>
	</div>

	<div class="idsk-search-results__filter-header-panel govuk-grid-column-full idsk-search-results--invisible">
		<div class="govuk-heading-xl idsk-search-results--half-width">
			<span><?php esc_html_e( 'Filters', 'idsk-template' ); ?></span>
		</div>
		<div class="idsk-search-results--half-width">
			<button class="idsk-search-results__button--back-to-results" type="button"><?php esc_html_e( 'Back to results', 'idsk-template' ); ?></button>
		</div>
	</div>

	<div class="idsk-search-results__filter govuk-grid-column-one-quarter">
		<?php
		if ( ! $main_search ) {
			?>
			<span class="idsk-intro-block__search__span"><?php esc_html_e( 'Search', 'idsk-template' ); ?></span>
			<div class="idsk-search-results__search-bar">
				<?php
				get_template_part(
					'inc/partials/search/bar',
					'',
					array(
						'type'  => 'small',
						'input' => $search_string,
					)
				);
				?>
			</div>
			<?php
		}
		?>

		<div class="idsk-search-results--order__dropdown">
			<div class="govuk-form-group">
				<label class="govuk-label" for="sort">
					<?php esc_html_e( 'Sort by', 'idsk-template' ); ?>
				</label>
				<select class="govuk-select" id="sort" onchange="startSearch('order', this.options[this.selectedIndex].value)">
					<option <?php echo 'relevance' === $ordered_by ? 'selected' : ''; ?> value="relevance"><?php esc_html_e( 'Relevance', 'idsk-template' ); ?></option>
					<option <?php echo 'DESC' === $ordered ? 'selected' : ''; ?> value="DESC"><?php esc_html_e( 'Descending', 'idsk-template' ); ?></option>
					<option <?php echo 'ASC' === $ordered ? 'selected' : ''; ?> value="ASC"><?php esc_html_e( 'Ascending', 'idsk-template' ); ?></option>
				</select>
			</div>
		</div>

		<?php
		/**
		 * Categories filter.
		 */
		$categories = get_categories(
			array(
				'taxonomy' => 'category',
				'parent'   => 0,
			)
		);

		$long_cats = count( $categories ) > 10 ? true : false;
		?>
		<div class="idsk-search-results__link-panel" tabindex="-1">
			<button class="idsk-search-results__link-panel-button " tabindex="0" type="button">
				<span class="idsk-search-results__link-panel__title">
					<?php esc_html_e( 'Category', 'idsk-template' ); ?>
				</span>
				<span class="idsk-search-results__link-panel--span" data-lines="<?php esc_attr_e( 'selected', 'idsk-template' ); ?>"></span>
			</button>

			<div class="idsk-search-results__list idsk-search-results--hidden">
				<?php
				if ( $long_cats ) {
					?>
					<input class="govuk-input idsk-search-results__search__input" type="text" title="<?php esc_attr_e( 'Filter category', 'idsk-template' ); ?>" id="idsk-search-input__subtopic">
					<?php
				}
				?>

				<div data-module="idsk-customer-surveys-radios" class="idsk-customer-surveys-radios ">
					<div class="govuk-radios" data-id="tema">
						<?php
						foreach ( $categories as $cats ) {
							echo '<div class="govuk-radios__item ">';
								echo '<input class="govuk-radios__input " id="' . esc_attr( $cats->term_id ) . '" name="cat" type="radio" value="' . esc_attr( get_cat_name( $cats->term_id ) ) . '" ' . ( $category === $cats->term_id ? 'checked' : '' ) . ' onchange="startSearch(this.name, this.id)">';
								echo '<label class="govuk-label govuk-radios__label" for="' . esc_attr( $cats->term_id ) . '">';
									echo esc_html( get_cat_name( $cats->term_id ) );
								echo '</label>';
							echo '</div>';
						}
						?>
						<br>
					</div>
				</div>
			</div>
		</div>

		<?php
		/**
		 * Subcategories filter.
		 */
		$sub_cats = ! empty( $category ) ? get_categories(
			array(
				'taxonomy' => 'category',
				'child_of' => $category,
			)
		) : array();

		$long_sub_cats = count( $sub_cats ) > 10 ? true : false;
		?>
		<div class="idsk-search-results__link-panel" tabindex="-1">
			<button class="idsk-search-results__link-panel-button idsk-search-results__subtopic" tabindex="0" type="button" <?php echo empty( $sub_cats ) ? 'disabled' : ''; ?>>
				<span class="idsk-search-results__link-panel__title">
					<?php esc_html_e( 'Subcategory', 'idsk-template' ); ?>
				</span>
				<span class="idsk-search-results__link-panel--span" data-lines="<?php esc_attr_e( 'selected', 'idsk-template' ); ?>"></span>
			</button>

			<div class="idsk-search-results__list idsk-search-results--hidden">
				<?php
				if ( $long_sub_cats ) {
					?>
					<input class="govuk-input idsk-search-results__search__input" type="text" title="<?php esc_attr_e( 'Filter subcategory', 'idsk-template' ); ?>" id="idsk-search-input__subtopic">
					<?php
				}
				?>

				<div data-module="idsk-customer-surveys-radios" class="idsk-customer-surveys-radios ">
					<div class="govuk-radios" data-id="podtema">
						<?php
						foreach ( $sub_cats as $sub_cat ) {
							echo '<div class="govuk-radios__item ">';
								echo '<input class="govuk-radios__input " id="' . esc_attr( $sub_cat->term_id ) . '" name="scat" type="radio" value="' . esc_attr( get_cat_name( $sub_cat->term_id ) ) . '" ' . ( (int) $sub_category === $sub_cat->term_id ? 'checked' : '' ) . ' onchange="startSearch(this.name, this.id)">';
								echo '<label class="govuk-label govuk-radios__label" for="' . esc_attr( $sub_cat->term_id ) . '">';
									echo esc_html( get_cat_name( $sub_cat->term_id ) );
								echo '</label>';
							echo '</div>';
						}
						?>
						<br>
					</div>
				</div>
			</div>
		</div>

		<?php
		/**
		 * Tags filter.
		 */
		$list_tags = get_tags();

		$long_tags = count( $list_tags ) > 10 ? true : false;
		?>
		<div class="idsk-search-results__link-panel <?php echo $long_tags ? 'idsk-search-results__content-type-filter' : ''; ?>" tabindex="-1">
			<button class="idsk-search-results__link-panel-button " tabindex="0" type="button">
				<span class="idsk-search-results__link-panel__title">
					<?php esc_html_e( 'Tags', 'idsk-template' ); ?>
				</span>
				<span class="idsk-search-results__link-panel--span" data-lines="<?php esc_attr_e( 'selected', 'idsk-template' ); ?>"></span>
			</button>

			<div class="idsk-search-results__list idsk-search-results--hidden">
				<?php
				if ( $long_tags ) {
					?>
					<input class="govuk-input idsk-search-results__search__input" type="text" title="<?php esc_attr_e( 'Filter tags', 'idsk-template' ); ?>" id="idsk-search-input__content-type">
					<?php
				}
				?>

				<div class="idsk-option-select-filter">
					<div class="govuk-form-group">
						<div class="govuk-checkboxes govuk-checkboxes--small">
							<?php
							foreach ( $list_tags as $ltag ) {
								echo '<div class="govuk-checkboxes__item">';
									echo '<input class="govuk-checkboxes__input " id="tag-' . esc_attr( $ltag->term_id ) . '" name="tags[]" type="checkbox" value="' . esc_attr( $ltag->name ) . '" ' . ( in_array( (string) $ltag->term_id, $tags, true ) ? 'checked' : '' ) . ' onchange="startSearch(this.name, ' . esc_attr( $ltag->term_id ) . ')">';
									echo '<label class="govuk-label govuk-checkboxes__label" for="tag-' . esc_attr( $ltag->term_id ) . '">';
										echo esc_html( $ltag->name );
									echo '</label>';
								echo '</div>';
							}
							?>
						</div>
					</div>
				</div>
			</div>
		</div>

		<?php
		/**
		 * Updated filter.
		 */
		?>
		<div class="idsk-search-results__link-panel" tabindex = "-1">
			<button class="idsk-search-results__link-panel-button" tabindex = "0" type="button">
				<span class="idsk-search-results__link-panel__title">
					<?php esc_html_e( 'Updated on', 'idsk-template' ); ?>
				</span>
				<span class="idsk-search-results__link-panel--span" data-lines="<?php esc_attr_e( 'selected', 'idsk-template' ); ?>"></span>
			</button>
			<div class="idsk-search-results__list idsk-search-results--hidden">
				<div class="govuk-form-group">
					<span class="idsk-search-results__date__span"><?php esc_html_e( 'Show only results updated after', 'idsk-template' ); ?></span>
					<span class="idsk-search-results__date__span__example"><?php esc_html_e( 'E.g. 2005 or 8.3.2021', 'idsk-template' ); ?></span>
					<span id="error-public_timestamp" class="govuk-error-message govuk-visually-hidden">
						<span class="govuk-visually-hidden"><?php esc_html_e( 'Error:', 'idsk-template' ); ?></span> <?php esc_html_e( 'Enter real date', 'idsk-template' ); ?>
					</span>
					<input class="govuk-input" type="text" name="datum-od" id="datum-od" value="<?php echo esc_attr( $date_from ); ?>" onchange="startSearch(this.name, this.value)">
				</div>
				<div class="govuk-form-group ">
					<span class="idsk-search-results__date__span"><?php esc_html_e( 'Show only results updated before', 'idsk-template' ); ?></span>
					<span class="idsk-search-results__date__span__example"><?php esc_html_e( 'E.g. 2005 or 8.3.2021', 'idsk-template' ); ?></span>
					<span id="error-public_timestamp" class="govuk-error-message govuk-visually-hidden">
						<span class="govuk-visually-hidden"><?php esc_html_e( 'Error:', 'idsk-template' ); ?></span> <?php esc_html_e( 'Enter real date', 'idsk-template' ); ?>
					</span>
					<input class="govuk-input" type="text" name="datum-do" id="datum-do" value="<?php echo esc_attr( $date_to ); ?>" onchange="startSearch(this.name, this.value)">
				</div>
			</div>
		</div>
	</div>
</form>
