<?php
/**
 * Cookies banner.
 *
 * Works only when the cookie banner is enabled.
 *
 * @link https://slovenskoit.sk
 *
 * @package WordPress
 * @subpackage ID-SK
 * @since ID-SK 1.3.0
 */

if ( true === get_theme_mod( 'idsktk_cookies_settings_banner', true ) ) {
	$heading       = get_theme_mod( 'idsktk_cookies_settings_banner_heading' );
	$body          = get_theme_mod( 'idsktk_cookies_settings_banner_text' );
	$buttons       = get_theme_mod( 'idsktk_cookies_settings_banner_buttons' );
	$accepted_body = get_theme_mod( 'idsktk_cookies_settings_banner_accepted' );
	$rejected_body = get_theme_mod( 'idsktk_cookies_settings_banner_rejected' );
	$page_link     = get_theme_mod( 'idsktk_cookies_settings_banner_page_link' );
	$allowed_html  = array(
		'p'      => array(
			'class' => array(),
		),
		'strong' => array(),
		'a'      => array(
			'href'       => array(),
			'title'      => array(),
			'class'      => array(),
			'target'     => array(),
			'aria-label' => array(),
			'id'         => array(),
		),
	);
	?>

	<div class="idsk-cookie-banner" data-nosnippet role="region" aria-label="<?php echo esc_attr( $heading ); ?>">
		<div class="idsk-cookie-banner__message idsk-cookies-message govuk-width-container">
			<div class="govuk-grid-row">
				<div class="govuk-grid-column-two-thirds">
					<?php
					if ( $heading ) {
						?>
						<h2 class="idsk-cookie-banner__heading govuk-heading-m"><?php echo esc_html( $heading ); ?></h2>
						<?php
					}
					?>

					<div class="idsk-cookie-banner__content">
						<p><?php echo wp_kses( $body, $allowed_html ); ?></p>
					</div>
				</div>
			</div>

			<?php
			if ( true === $buttons || $page_link ) {
				?>
				<div class="idsk-button-group">
					<?php
					if ( true === $buttons ) {
						?>
						<button type="button" name="cookies" class="idsk-button idsk-cookies-accept" data-module="idsk-button">
							<?php esc_html_e( 'Accept cookies', 'idsk-template' ); ?>
						</button>
						<button type="button" name="cookies" class="idsk-button idsk-cookies-reject" data-module="idsk-button">
							<?php esc_html_e( 'Reject cookies', 'idsk-template' ); ?>
						</button>
						<?php
					}

					if ( $page_link ) {
						?>
						<a class="govuk-link" href="<?php echo esc_url( $page_link ); ?>" title="<?php esc_attr_e( 'Cookies settings', 'idsk-template' ); ?>"><?php esc_html_e( 'Cookies settings', 'idsk-template' ); ?></a>
						<?php
					}
					?>
				</div>
				<?php
			}
			?>
		</div>

		<div class="idsk-cookie-banner__message govuk-width-container idsk-cookies-accepted app-width-container" role="alert" hidden>
			<div class="govuk-grid-row">
				<div class="govuk-grid-column-two-thirds">
					<div class="idsk-cookie-banner__content">
						<?php
						if ( $accepted_body ) {
							?>
							<p><?php echo wp_kses( $accepted_body, $allowed_html ); ?></p>
							<?php
						} else {
							?>
							<p><?php esc_html_e( 'You have accepted cookies, you can change this option at any time in', 'idsk-template' ); ?> <a class="govuk-link" href="<?php echo esc_url( $page_link ); ?>" title="<?php esc_attr_e( 'cookies settings page', 'idsk-template' ); ?>"><?php esc_html_e( 'cookies settings page', 'idsk-template' ); ?></a>.</p>
							<?php
						}
						?>
					</div>
				</div>
			</div>

			<div class="idsk-button-group">
				<button type="button" class="idsk-button idsk-cookies-hide" data-module="idsk-button">
					<?php esc_html_e( 'Hide message', 'idsk-template' ); ?>
				</button>
			</div>
		</div>

		<div class="idsk-cookie-banner__message govuk-width-container idsk-cookies-rejected app-width-container" role="alert" hidden>
			<div class="govuk-grid-row">
				<div class="govuk-grid-column-two-thirds">
					<div class="idsk-cookie-banner__content">
						<?php
						if ( $rejected_body ) {
							?>
							<p><?php echo wp_kses( $rejected_body, $allowed_html ); ?></p>
							<?php
						} else {
							?>
							<p><?php esc_html_e( 'You have rejected any additional cookies, you can change this option at any time in', 'idsk-template' ); ?> <a class="govuk-link" href="<?php echo esc_url( $page_link ); ?>" title="<?php esc_attr_e( 'cookies settings page', 'idsk-template' ); ?>"><?php esc_html_e( 'cookies settings page', 'idsk-template' ); ?></a>.</p>
							<?php
						}
						?>
					</div>
				</div>
			</div>

			<div class="idsk-button-group">
				<button type="button" class="idsk-button idsk-cookies-hide" data-module="idsk-button">
					<?php esc_html_e( 'Hide message', 'idsk-template' ); ?>
				</button>
			</div>
		</div>

	</div>
	<?php
}
