<?php
/**
 * Language switcher.
 *
 * @link https://slovenskoit.sk
 *
 * @package WordPress
 * @subpackage ID-SK
 * @since ID-SK 1.3.0
 */

$current_lang      = '';
$langs             = array();
$custom_link_attrs = '';

if ( class_exists( 'TRP_Translate_Press' ) ) {
	/**
	 * Support for TranslatePress plugin.
	 *
	 * @link https://wordpress.org/plugins/translatepress-multilingual/
	 */
	// Current language.
	global $TRP_LANGUAGE; // phpcs:ignore WordPress.NamingConventions.ValidVariableName.VariableNotSnakeCase -- TranslatePress global

	$trp                 = TRP_Translate_Press::get_trp_instance();
	$trp_settings_object = new TRP_Settings();
	$trp_settings        = $trp_settings_object->get_settings();
	$trp_languages       = $trp->get_component( 'languages' );
	$trp_settings        = $trp->get_component( 'settings' );
	$trp_url_converter   = $trp->get_component( 'url_converter' );

	if ( current_user_can( apply_filters( 'trp_translating_capability', 'manage_options' ) ) ) {
		$languages_to_display = $trp_settings['translation-languages'];
	} else {
		$languages_to_display = $trp_settings['publish-languages'];
	}
	$published_languages = $trp_languages->get_language_names( $languages_to_display );

	foreach ( $published_languages as $code => $name ) {
		$langs[ $code ]['name'] = $name;
		$langs[ $code ]['url']  = $trp_url_converter->get_url_for_language( $code, false );
		if ( $code === $TRP_LANGUAGE ) { // phpcs:ignore WordPress.NamingConventions.ValidVariableName.VariableNotSnakeCase -- TranslatePress global
			$langs[ $code ]['current_lang'] = true;
			$current_lang                   = $name;
		} else {
			$langs[ $code ]['current_lang'] = false;
		}
	}
} elseif ( function_exists( 'pll_the_languages' ) ) {
	/**
	 * Support for Polylang plugin.
	 *
	 * @link https://wordpress.org/plugins/polylang/
	 */
	$langs = pll_the_languages(
		array(
			'raw'           => 1,
			'hide_if_empty' => 0,
		)
	);

	$current_lang = $langs[ pll_current_language() ]['name'];
} elseif ( function_exists( 'weglot_get_original_language' ) ) {
	/**
	 * Support for Weglot plugin.
	 *
	 * @link https://wordpress.org/plugins/weglot/
	 */
	$custom_link_attrs = 'data-wg-notranslate';

	$current_this        = weglot_get_service( 'Button_Service_Weglot' );
	$request_url_service = weglot_get_service( 'Request_Url_Service_Weglot' );
	$language_service    = weglot_get_service( 'Language_Service_Weglot' );

	$original_language    = weglot_get_original_language();
	$destination_language = weglot_get_destination_languages();

	$current_language = $request_url_service->get_current_language( false );

	if ( ! empty( $original_language ) && ! empty( $destination_language ) ) {
		$current_language_entry = $language_service->get_language_from_internal( $current_language->getInternalCode() );
		$current_lang           = $current_this->get_name_with_language_entry( $current_language_entry );

		array_unshift( $destination_language, $original_language );

		foreach ( $language_service->get_original_and_destination_languages( $request_url_service->is_allowed_private() ) as $language ) {
			$code = $language->getInternalCode();

			$langs[ $code ]['name']         = $current_this->get_name_with_language_entry( $language );
			$langs[ $code ]['url']          = $request_url_service->get_weglot_url()->getForLanguage( $language );
			$langs[ $code ]['current_lang'] = $code === $current_language->getInternalCode();
		}
	}
}

if ( ! empty( $langs ) ) {
	?>
	<div class="idsk-header-web__brand-language">
		<button class="idsk-header-web__brand-language-button"
			aria-label="<?php esc_attr_e( 'Expand language menu', 'idsk-template' ); ?>" aria-expanded="false"
			data-text-for-hide="<?php esc_attr_e( 'Hide language menu', 'idsk-template' ); ?>"
			data-text-for-show="<?php esc_attr_e( 'Expand language menu', 'idsk-template' ); ?>"
		>
			<?php echo esc_html( $current_lang ); ?>
			<div class="idsk-header-web__link-arrow"></div>
		</button>
		<ul class="idsk-header-web__brand-language-list">
			<?php
			foreach ( $langs as $lang ) {
				?>
				<li class="idsk-header-web__brand-language-list-item">
					<a class="govuk-link idsk-header-web__brand-language-list-item-link <?php echo $lang['current_lang'] ? 'idsk-header-web__brand-language-list-item-link--selected' : ''; ?>"
						<?php echo esc_attr( $custom_link_attrs ); ?>
						href="<?php echo esc_url( $lang['url'] ); ?>"
						title="<?php echo esc_attr( $lang['name'] ); ?>"
					>
						<?php echo esc_html( $lang['name'] ); ?>
					</a>
				</li>
				<?php
			}
			?>
		</ul>
	</div>
	<?php
}
