<?php
/**
 * Main menu navigation.
 *
 * @link https://slovenskoit.sk
 *
 * @package WordPress
 * @subpackage ID-SK
 * @since ID-SK 1.0
 */

$menu_name = 'primary_menu';
$locations = get_nav_menu_locations();

if ( has_nav_menu( $menu_name ) && ! empty( $locations ) && isset( $locations[ $menu_name ] ) ) {
	$primary_menu = wp_get_nav_menu_object( $locations[ $menu_name ] );
	$menu_items   = wp_get_nav_menu_items( $primary_menu->term_id );
	$primary_menu = array();

	foreach ( (array) $menu_items as $menu_item ) {
		$item = array(
			'active' => get_queried_object_id() === $menu_item->object_id ? 'idsk-header-web__nav-list-item--active' : '',
			'title'  => $menu_item->title,
			'url'    => $menu_item->url,
		);

		// If has parent, give him back to his parent!
		if ( $menu_item->menu_item_parent ) {
			$primary_menu[ $menu_item->menu_item_parent ]['submenu'][] = $item;
		} else {
			$primary_menu[ $menu_item->ID ] = $item;
		}
	}
	?>

	<nav class="idsk-header-web__nav-bar--buttons">
		<ul class="idsk-header-web__nav-list " role="navigation" aria-label="<?php esc_attr_e( 'Main navigation', 'idsk-template' ); ?>">
			<?php
			foreach ( $primary_menu as $item ) {
				$has_submenu  = isset( $item['submenu'] ) && count( $item['submenu'] ) ? true : false;
				$lite_submenu = isset( $item['submenu'] ) && count( $item['submenu'] ) < 6 ? true : false;
				$url          = $has_submenu ? '#' : $item['url'];
				?>
				<li class="idsk-header-web__nav-list-item <?php echo isset( $item['active'] ) ? esc_attr( $item['active'] ) : ''; ?>">
					<a
						class="govuk-link idsk-header-web__nav-list-item-link"
						href="<?php echo esc_url( $url ); ?>"
						title="<?php echo isset( $item['title'] ) ? esc_attr( $item['title'] ) : ''; ?>"
						<?php
						if ( $has_submenu ) {
							?>
							aria-label="<?php echo esc_attr__( 'Expand', 'idsk-template' ) . ( isset( $item['title'] ) ? ' ' . esc_attr( $item['title'] ) : '' ) . ' ' . esc_attr__( 'menu', 'idsk-template' ); ?>"
							aria-expanded="false"
							data-text-for-hide="<?php echo esc_attr__( 'Hide', 'idsk-template' ) . ( isset( $item['title'] ) ? ' ' . esc_attr( $item['title'] ) : '' ) . ' ' . esc_attr__( 'menu', 'idsk-template' ); ?>"
							data-text-for-show="<?php echo esc_attr__( 'Expand', 'idsk-template' ) . ( isset( $item['title'] ) ? ' ' . esc_attr( $item['title'] ) : '' ) . ' ' . esc_attr__( 'menu', 'idsk-template' ); ?>"
							<?php
						}
						?>
					>
						<?php
						echo isset( $item['title'] ) ? esc_html( $item['title'] ) : '';

						if ( $has_submenu ) {
							?>
							<div class="idsk-header-web__link-arrow"></div>
							<div class="idsk-header-web__link-arrow-mobile"></div>
							<?php
						}
						?>
					</a>

					<?php
					if ( $has_submenu ) {
						?>
						<div class="<?php echo $lite_submenu ? 'idsk-header-web__nav-submenulite' : 'idsk-header-web__nav-submenu'; ?>">
							<?php
							if ( ! $lite_submenu ) {
								?>
								<div class="govuk-width-container">
									<div class="govuk-grid-row">
								<?php
							}
							?>

							<ul class="<?php echo $lite_submenu ? 'idsk-header-web__nav-submenulite-list' : 'idsk-header-web__nav-submenu-list'; ?>" aria-label="<?php esc_attr_e( 'Internal navigation', 'idsk-template' ); ?>">
								<?php
								foreach ( $item['submenu'] as $sub_item ) {
									?>
									<li class="<?php echo $lite_submenu ? 'idsk-header-web__nav-submenulite-list-item' : 'idsk-header-web__nav-submenu-list-item'; ?>">
										<a href="<?php echo isset( $sub_item['url'] ) ? esc_url( $sub_item['url'] ) : '#'; ?>"
											title="<?php echo isset( $sub_item['title'] ) ? esc_attr( $sub_item['title'] ) : ''; ?>"
											class="govuk-link <?php echo $lite_submenu ? 'idsk-header-web__nav-submenulite-list-item-link' : 'idsk-header-web__nav-submenu-list-item-link'; ?>">
											<span><?php echo isset( $sub_item['title'] ) ? esc_html( $sub_item['title'] ) : ''; ?></span>
										</a>
									</li>
									<?php
								}
								?>
							</ul>

							<?php
							if ( ! $lite_submenu ) {
								?>
									</div>
								</div>
								<?php
							}
							?>
						</div>
						<?php
					}
					?>
				</li>
				<?php
			}
			?>
		</ul>
	</nav>
	<?php
}
