<?php
/**
 * Custom template tags for this theme.
 *
 * @link https://slovenskoit.sk
 *
 * @package WordPress
 * @subpackage ID-SK
 * @since ID-SK 1.0
 */

if ( ! function_exists( 'idsktmp_comment' ) ) {
	/**
	 * Print custom comment view.
	 *
	 * @param WP_Comment $comment Comment to display.
	 * @param array      $args    An array of arguments.
	 * @param int        $depth   Depth of the current comment.
	 */
	function idsktmp_comment( $comment, $args, $depth ) {
		if ( 'div' === $args['style'] ) {
			$tag       = 'div';
			$add_below = 'comment';
		} else {
			$tag       = 'div';
			$add_below = 'div-comment';
		}

		echo '<' . esc_attr( $tag ) . ' ' . comment_class( empty( $args['has_children'] ) ? 'govuk-body' : 'govuk-body parent', '', '', false ) . ' id="comment-' . esc_attr( get_comment_id() ) . '">';

		if ( 'div' !== $args['style'] ) {
			echo '<div id="div-comment-' . esc_attr( get_comment_id() ) . '" class="comment-body">';
		}

		echo '<div class="comment-author vcard">';
		/* translators: %s: comment author */
		printf( esc_html__( '%s is writing:', 'idsk-template' ), '<strong>' . esc_html( get_comment_author() ) . '</strong>' );
		echo '</div>';

		if ( '0' === $comment->comment_approved ) {
			echo '<em class="comment-awaiting-moderation">' . esc_html__( 'Your comment is awaiting approval.', 'idsk-template' ) . '</em><br/>';
		}

		echo '<div class="comment-meta commentmetadata">';
		echo '<a href="' . esc_url( get_comment_link( $comment->comment_ID ) ) . '" class="govuk-link">';
		printf(
			/* translators: 1: date, 2: time */
			esc_html__( '%1$s at %2$s', 'idsk-template' ),
			esc_html( get_comment_date() ),
			esc_html( get_comment_time() )
		);
		echo '</a> ';
		edit_comment_link( esc_html__( '(Edit)', 'idsk-template' ) );
		echo '</div>';

		comment_text();

		echo '<div class="reply">';
		comment_reply_link(
			array_merge(
				$args,
				array(
					'add_below' => $add_below,
					'depth'     => $depth,
					'max_depth' => $args['max_depth'],
				)
			)
		);
		echo '</div>';

		if ( 'div' !== $args['style'] ) {
			echo '</div>';
		}

		echo '<hr class="govuk-section-break govuk-section-break--m govuk-section-break--visible" style="clear: both;">';
	}
}

if ( ! function_exists( 'idsktmp_get_breadcrumb' ) ) {
	/**
	 * Print custom breadcrumbs.
	 */
	function idsktmp_get_breadcrumb() {
		global $post;

		echo '<div class="govuk-breadcrumbs">';
		echo '<ol class="govuk-breadcrumbs__list">';
		echo '<li class="govuk-breadcrumbs__list-item"><a class="govuk-breadcrumbs__link" href="' . esc_url( home_url() ) . '">' . esc_html__( 'Home', 'idsk-template' ) . '</a></li>';

		if ( is_search() ) {
			echo '<li class="govuk-breadcrumbs__list-item" aria-current="page">';
			printf(
				/* translators: %s: search term. */
				esc_html__( 'Results for "%s"', 'idsk-template' ),
				'<em>' . esc_html( get_search_query() ) . '</em>'
			);
			echo '</li>';
		} elseif ( is_category() || is_single() ) {
			the_category();

			if ( is_single() ) {
				the_title( '<li class="govuk-breadcrumbs__list-item" aria-current="page">', '</li>' );
			}
		} elseif ( is_page() ) {
			if ( $post->post_parent ) {
				$parents = get_post_ancestors( $post->post_parent ); // Get all parents of parent.
				// Display all parents.
				if ( ! empty( $parents ) ) {
					foreach ( $parents as $parent ) {
						echo '<li class="govuk-breadcrumbs__list-item"><a class="govuk-breadcrumbs__link" href="' . esc_url( get_permalink( $parent ) ) . '">' . esc_html( get_the_title( $parent ) ) . '</a></li>';
					}
				}
				echo '<li class="govuk-breadcrumbs__list-item"><a class="govuk-breadcrumbs__link" href="' . esc_url( get_permalink( $post->post_parent ) ) . '">' . esc_html( get_the_title( $post->post_parent ) ) . '</a></li>';
			}

			the_title( '<li class="govuk-breadcrumbs__list-item" aria-current="page">', '</li>' );
		}
		echo '</ol>';
		echo '</div>';
	}
}

if ( ! function_exists( 'idsktmp_posts_pagination' ) ) {
	/**
	 * Print custom posts pagination.
	 */
	function idsktmp_posts_pagination() {
		$post_pages = paginate_links(
			array(
				'echo'      => false,
				'type'      => 'array',
				'prev_text' => sprintf(
					'%s %s',
					is_rtl() ? esc_html__( '>', 'idsk-template' ) : esc_html__( '<', 'idsk-template' ),
					esc_html__( 'Newer articles', 'idsk-template' )
				),
				'next_text' => sprintf(
					'%s %s',
					esc_html__( 'Older articles', 'idsk-template' ),
					is_rtl() ? esc_html__( '<', 'idsk-template' ) : esc_html__( '>', 'idsk-template' )
				),
			)
		);

		if ( is_array( $post_pages ) ) {
			$output = '';

			foreach ( $post_pages as $post_page ) {
				$custom_page = str_replace( '<a class="', '<a class="govuk-button govuk-button--secondary ', $post_page );
				$custom_page = str_replace( '<span aria-current="page" class="', '<span aria-current="page" class="govuk-button ', $custom_page );

				$output .= $custom_page;
			}

			echo wp_kses(
				$output,
				array(
					'a'    => array(
						'href'  => array(),
						'class' => array(),
						'title' => array(),
					),
					'span' => array(
						'aria-current' => array(),
						'class'        => array(),
					),
				)
			);
		}
	}
}

if ( ! function_exists( 'idsktmp_post_detail' ) ) {
	/**
	 * Print custom post style.
	 *
	 * @param array  $data  Post data.
	 * @param string $class Custom class.
	 */
	function idsktmp_post_detail( $data, $class = 'hero' ) {
		$output = '<div class="idsk-card idsk-card-' . esc_attr( $class ) . '">
			<a href="' . esc_url( $data['url'] ) . '" title="' . esc_attr( $data['title'] ) . '">
				<img class="idsk-card-img idsk-card-img-' . esc_attr( $class ) . '" width="100%" src="' . esc_url( $data['image'] ) . '" alt="' . esc_attr( $data['title'] ) . '" aria-hidden="true" />
			</a>

			<div class="idsk-card-content idsk-card-content-' . esc_attr( $class ) . '">
				<div class="idsk-card-meta-container">
					<span class="idsk-card-meta idsk-card-meta-date">
						<a href="' . esc_url( $data['url'] ) . '" class="govuk-link" title="' . esc_attr( __( 'Created on:', 'idsk-template' ) . ' ' . $data['created'] ) . '">' . esc_html( $data['created'] ) . '</a>
					</span>';

		foreach ( $data['categories'] as $category ) {
			$output .= '<span class="idsk-card-meta idsk-card-meta-tag">
				<a href="' . esc_url( get_category_link( $category ) ) . '" class="govuk-link" title="' . esc_attr( $category->name ) . '">' . esc_html( $category->name ) . '</a>
			</span>';
		}

		$output .= '</div>

				<div class="idsk-heading idsk-heading-' . esc_attr( $class ) . '">
					<a href="' . esc_url( $data['url'] ) . '" class="idsk-card-title govuk-link" title="' . esc_attr( $data['title'] ) . '">' . wp_kses_post( $data['title'] ) . '</a>
				</div>

				<p class="idsk-body idsk-body-' . esc_attr( $class ) . '">' . wp_kses_post( $data['excerpt'] ) . '</p>
			</div>
		</div>';

		echo wp_kses_post( $output );
	}
}

if ( ! function_exists( 'wp_body_open' ) ) {
	/**
	 * Fire the wp_body_open action.
	 *
	 * Added for backward compatibility to support pre-5.2.0 WordPress versions.
	 */
	function wp_body_open() {
		/**
		 * Triggered after the opening <body> tag.
		 */
		do_action( 'wp_body_open' );
	}
}
