<?php
/**
 * The template for displaying all search results.
 *
 * @link https://slovenskoit.sk
 *
 * @package WordPress
 * @subpackage ID-SK
 * @since ID-SK 1.1.0
 */

$advanced_search = function_exists( 'idsktk_advanced_search_query' );
$posts_per_page  = array( 5, 10, 20, 30, 50, 100, 200, 300, 400, 500 );

// Get query order.
$ordered_by = get_query_var( 'orderby' );
if ( empty( $ordered_by ) ) {
	$ordered = get_query_var( 'order' );
} else {
	$ordered = '';
}

// Used when advanced search is not availiable.
$actual_page = get_query_var( 'paged' ) ? get_query_var( 'paged' ) : 1;
$max_paged   = $wp_query->max_num_pages ? $wp_query->max_num_pages : 1;

get_header();
?>

<div class="govuk-width-container">
	<div class="govuk-width-container">

		<div class="govuk-grid-row">

			<div class="idsk-search-results" data-module="idsk-search-results">
				<div class="govuk-grid-column-full idsk-search-results__title">
					<h1 class="govuk-heading-xl">
						<?php
						printf(
							/* translators: %s: search term. */
							esc_html__( 'Results for "%s"', 'idsk-template' ),
							'<small>' . esc_html( get_search_query() ) . '</small>'
						);
						?>
					</h1>
				</div>

				<?php
				if ( $advanced_search ) {
					get_template_part( 'inc/partials/advanced', 'searchform' );
					?>
					<div class="idsk-search-results__content govuk-grid-column-three-quarters">
					<?php
				} else {
					?>
					<form role="search" method="get" action="<?php echo esc_url( home_url( '/' ) ); ?>">
						<div class="govuk-grid-column-full idsk-search-results__search-bar">
							<?php
							get_template_part(
								'inc/partials/search/bar',
								'',
								array(
									'input' => get_search_query(),
								)
							);
							?>
						</div>
					</form>

					<div class="idsk-search-results__content govuk-grid-column-full">
					<?php
				}
				?>

				<div class="govuk-grid-column-one-quarter">
					<span class="idsk-search-results__content__number-of-results">
						<?php
						printf(
							esc_html(
								/* translators: %d: the number of search results. */
								_n(
									'%d result',
									'%d results',
									(int) $wp_query->found_posts,
									'idsk-template'
								)
							),
							(int) $wp_query->found_posts
						);
						?>
					</span>
				</div>

				<div class="govuk-grid-column-two-quarters idsk-search-results__filter-panel--mobile">
					<?php
					if ( $advanced_search ) {
						?>
						<button class="idsk-search-results__filters__button" title="<?php esc_attr_e( 'Filters', 'idsk-template' ); ?>">
							<?php esc_html_e( 'Filters', 'idsk-template' ); ?>
						</button>
						<div class="idsk-search-results__per-page">
							<span><?php esc_html_e( 'Results per page', 'idsk-template' ); ?></span>
							<div class="govuk-form-group">
								<select class="govuk-select" id="sort" name="sort">
									<?php
									foreach ( $posts_per_page as $ppp ) {
										echo '<option value="' . esc_attr( $ppp ) . '">' . esc_html( $ppp ) . '</option>';
									}
									?>
								</select>
							</div>
						</div>
						<?php
					}
					?>
				</div>

				<div class="idsk-search-results--order">
					<?php
					if ( $advanced_search ) {
						?>
						<div class="govuk-form-group">
							<label class="govuk-label" for="sort">
								<?php esc_html_e( 'Sort', 'idsk-template' ); ?> <strong>
									<?php
									printf(
										esc_html(
											/* translators: %d: the number of search results. */
											_n(
												'%d result',
												'%d results',
												(int) $wp_query->found_posts,
												'idsk-template'
											)
										),
										(int) $wp_query->found_posts
									);
									?>
								</strong> <?php esc_html_e( 'by', 'idsk-template' ); ?>
							</label>
							<select class="govuk-select" id="sort" onchange="startSearch('order', this.options[this.selectedIndex].value)">
								<option <?php echo 'relevance' === $ordered_by ? 'selected' : ''; ?> value="relevance"><?php esc_html_e( 'Relevance', 'idsk-template' ); ?></option>
								<option <?php echo 'DESC' === $ordered ? 'selected' : ''; ?> value="DESC"><?php esc_html_e( 'Descending', 'idsk-template' ); ?></option>
								<option <?php echo 'ASC' === $ordered ? 'selected' : ''; ?> value="ASC"><?php esc_html_e( 'Ascending', 'idsk-template' ); ?></option>
							</select>
						</div>
						<?php
					}
					?>
				</div>

				<?php
				if ( $advanced_search ) {
					get_template_part(
						'inc/partials/search/pagination',
						'',
						array(
							'type'   => 'advanced',
							'actual' => '$value1',
							'max'    => '$value2',
						)
					);
				} else {
					get_template_part(
						'inc/partials/search/pagination',
						'',
						array(
							'actual' => $actual_page,
							'max'    => $max_paged,
						)
					);
				}
				?>

				<div class="idsk-search-results__content__picked-filters govuk-grid-column-full idsk-search-results--invisible__mobile">
					<div class="idsk-search-results__content__picked-filters__topics idsk-search-results--invisible">
						<span class="idsk-search-results__text"><?php esc_html_e( 'Only in categories', 'idsk-template' ); ?></span>
					</div>
					<div class="idsk-search-results__content__picked-filters__content-type idsk-search-results--invisible">
						<span class="idsk-search-results__text"><?php esc_html_e( 'Tags', 'idsk-template' ); ?></span>
					</div>
					<div class="idsk-search-results__content__picked-filters__date idsk-search-results--invisible"
						data-lines="<?php esc_attr_e( 'Last updated', 'idsk-template' ); ?>"
						data-after="<?php esc_attr_e( 'after', 'idsk-template' ); ?>"
						data-middle="<?php esc_attr_e( 'between', 'idsk-template' ); ?>"
						data-before="<?php esc_attr_e( 'before', 'idsk-template' ); ?>">
					</div>
					<button class="idsk-search-results__button--turn-filters-off govuk-grid-column-full idsk-search-results--invisible" type="button">
						<?php esc_html_e( 'Disable all filters', 'idsk-template' ); ?>
					</button>
				</div>

				<div class="govuk-grid-column-full idsk-search-results__show-results__button idsk-search-results--invisible">
					<button class="govuk-button idsk-search-results__button-show-results" type="button">
						<?php
						esc_html_e( 'Show', 'idsk-template' );
						echo ' ';
						printf(
							esc_html(
								/* translators: %d: the number of search results. */
								_n(
									'%d result',
									'%d results',
									(int) $wp_query->found_posts,
									'idsk-template'
								)
							),
							(int) $wp_query->found_posts
						);
						?>
					</button>
				</div>

				<div class="idsk-search-results__content__all">
					<?php
					if ( have_posts() ) {

						// Start the Loop.
						while ( have_posts() ) {
							the_post();
							?>
							<div class="idsk-search-results__card govuk-grid-column-full">
								<div class="idsk-card idsk-card-basic-variant">
									<div class="idsk-card-content idsk-card-content-basic-variant">
										<div class="idsk-heading idsk-heading-basic-variant">
											<?php
											echo '<a href="' . esc_url( get_the_permalink() ) . '" class="idsk-card-title govuk-link" title="' . esc_attr( get_the_title() ) . '">';
											if ( get_the_title() ) {
												the_title();
											} else {
												// If no title is present, show the date.
												the_date();
											}
											echo '</a>';
											?>
										</div>
										<p class="idsk-body idsk-body-basic-variant">
											<?php echo esc_html( get_the_excerpt() ); ?>
										</p>
									</div>
								</div>

								<?php
								// Display subpages.
								$sub_pages = get_pages( array( 'child_of' => get_the_ID() ) );

								if ( ! empty( $sub_pages ) ) {
									foreach ( $sub_pages as $sub_page ) {
										?>
										<div class="govuk-grid-column-one-half idsk-search-results__subcards">
											<div class="idsk-card idsk-card-basic-variant">
												<div class="idsk-card-content idsk-card-content-basic-variant">
													<div class="idsk-heading idsk-heading-basic-variant">
														<?php echo '<a href="' . esc_url( get_page_link( $sub_page->ID ) ) . '" class="idsk-card-title govuk-link" title="' . esc_attr( $sub_page->post_title ) . '">' . esc_html( $sub_page->post_title ) . '</a>'; ?>
													</div>
													<p class="idsk-body idsk-body-basic-variant">
														<?php echo esc_html( get_the_excerpt( $sub_page->ID ) ); ?>
													</p>
												</div>
											</div>
										</div>
										<?php
									}
								}
								?>
							</div>
							<?php
						} // End the loop.
					} else {
						?>
						<div class="idsk-search-results__card govuk-grid-column-full">
							<div class="idsk-card idsk-card-basic-variant">
								<div class="idsk-card-content idsk-card-content-basic-variant">
									<div class="idsk-heading idsk-heading-basic-variant"></div>
									<p class="idsk-body idsk-body-basic-variant">
										<?php esc_html_e( 'No results found.', 'idsk-template' ); ?>
									</p>
								</div>
							</div>
						</div>
						<?php
					}
					?>
				</div>

				<?php
				if ( $advanced_search ) {
					get_template_part(
						'inc/partials/search/pagination',
						'',
						array(
							'type'   => 'advanced',
							'style'  => 'expanded',
							'actual' => '$value1',
							'max'    => '$value2',
						)
					);
				} else {
					get_template_part(
						'inc/partials/search/pagination',
						'',
						array(
							'style'  => 'expanded',
							'actual' => $actual_page,
							'max'    => $max_paged,
						)
					);
				}
				?>

				</div>
			</div>
		</div>
	</div>
</div>

<?php
get_footer();
