<?php
/**
 * The template for displaying all single posts.
 *
 * @link https://slovenskoit.sk
 *
 * @package WordPress
 * @subpackage ID-SK
 * @since ID-SK 1.3.0
 */

get_header();
?>
<div class="govuk-width-container">
	<?php
	if ( have_posts() ) {
		$updated_list_allow   = get_post_meta( get_the_ID(), 'idsktk_allow_post_updates_list', true );
		$socials_allow        = get_post_meta( get_the_ID(), 'idsktk_allow_post_social', true );
		$related_topics_allow = get_post_meta( get_the_ID(), 'idsktk_allow_post_related_topics', true );
		$related_posts_allow  = get_post_meta( get_the_ID(), 'idsktk_allow_post_related_posts', true );
		$related_posts        = get_post_meta( get_the_ID(), 'idsktk_post_related_posts_fields', true );
		$related_posts_list   = array();

		if ( ! empty( $related_posts ) ) {
			foreach ( $related_posts as $item ) {
				$related_posts_list[] = array(
					'url'   => get_permalink( $item['id'] ),
					'title' => get_the_title( $item['id'] ),
				);
			}
		}

		$args_updates = array(
			'allow' => ! empty( $updated_list_allow ) ? true : false,
			'items' => get_post_meta( get_the_ID(), 'idsktk_post_updates_list_fields', true ),
		);
		// Be sure to have same ID for inpage navigation item, if you want related content to be displayed there.
		$args_topics = array(
			'id'    => 'post-related-topics',
			'title' => __( 'Related topics', 'idsk-template' ),
			'items' => get_post_meta( get_the_ID(), 'idsktk_post_related_topics_fields', true ),
		);
		$args_posts  = array(
			'id'    => 'post-related-posts',
			'title' => __( 'Related articles', 'idsk-template' ),
			'items' => $related_posts_list,
		);
		?>

		<div class="govuk-grid-row">
			<div class="govuk-grid-column-three-quarters-from-desktop idsk-article-pattern__element-right">
				<div id="uvod">
					<span class="govuk-caption-xl idsk-article-pattern__subtitle"><?php esc_html_e( 'Actuality', 'idsk-template' ); ?></span>
					<?php the_title( '<h2 class="govuk-heading-l idsk-stepper-pattern__intro-heading">', '</h2>' ); ?>
				</div>

				<?php
				$args_updates['type'] = 'top';
				get_template_part( 'inc/partials/post/list', 'update', $args_updates );
				?>
			</div>

			<?php get_template_part( 'inc/partials/inpage' ); ?>

			<div class="govuk-grid-column-three-quarters-from-desktop">
				<?php
				// Load posts loop.
				while ( have_posts() ) {
					the_post();
					the_content();
				}

				$args_updates['type'] = 'bottom';
				get_template_part( 'inc/partials/post/list', 'update', $args_updates );

				if ( ! empty( $socials_allow ) ) {
					?>
					<div class="govuk-grid-column-full idsk-article__social-networks">
						<br/>
						<p class="govuk-body-s govuk-!-font-weight-bold"><?php esc_html_e( 'Share this article', 'idsk-template' ); ?></p>
						<?php
						get_template_part(
							'inc/partials/link',
							'share',
							array(
								'title' => __( 'Facebook', 'idsk-template' ),
								'url'   => 'https://www.facebook.com/sharer/sharer.php?u=' . get_permalink(),
								'img'   => array(
									get_template_directory_uri() . '/assets/images/fb-logo.svg',
									get_template_directory_uri() . '/assets/images/fb.svg',
								),
							)
						);
						echo '&nbsp;';
						get_template_part(
							'inc/partials/link',
							'share',
							array(
								'title' => __( 'LinkedIn', 'idsk-template' ),
								'url'   => 'https://www.linkedin.com/sharing/share-offsite/?url=' . get_permalink(),
								'img'   => array(
									get_template_directory_uri() . '/assets/images/li-logo.svg',
									get_template_directory_uri() . '/assets/images/li.svg',
								),
							)
						);
						?>
					</div>
					<?php
				}

				if ( ! empty( $related_topics_allow ) ) {
					get_template_part( 'inc/partials/post/content', 'related', $args_topics );
				}

				if ( ! empty( $related_posts_allow ) ) {
					get_template_part( 'inc/partials/post/content', 'related', $args_posts );
				}

				if ( comments_open() || get_comments_number() ) {
					comments_template();
				}
				?>
			</div>
		</div>
		<?php
	}
	?>
</div>
<?php
get_footer();
